
#include <project.h>

#define BUFFER_SIZE 64
   
/* Defines for DMA */
#define DMA_BYTES_PER_BURST 2
#define DMA_REQUEST_PER_BURST 1
#define DMA_SRC_BASE (CYDEV_PERIPH_BASE)
#define DMA_DST_BASE (CYDEV_PERIPH_BASE)


/* DMA Configuration for DMA_1 */
#define DMA_1_BYTES_PER_BURST 2
#define DMA_1_REQUEST_PER_BURST 1
#define DMA_1_SRC_BASE (CYDEV_PERIPH_BASE)
#define DMA_1_DST_BASE (CYDEV_SRAM_BASE)
/* Variable declarations for DMA */
/* Move these variable declarations to the top of the function */
uint8 DMA_Chan;
uint8 DMA_TD[1];

/* Variable declarations for DMA_1 */
/* Move these variable declarations to the top of the function */
uint8 DMA_1_Chan;
uint8 DMA_1_TD[1];

extern volatile uint8 USBUART_cdc_data_in_ep;
uint8 adc_muestra[BUFFER_SIZE]= {0}; 
void DMA_Config(void);
void DMA_1_Config(void);

uint8 DMA_done = 0;

int main()
{   
    DMA_Config();
    DMA_1_Config();
    /* Start all components used on schematic */
    ADC_Start();
    ADC_IRQ_Disable();
    ADC_StartConvert();
 
    isr_Done_Start();
    Filter_Start();

    /* User-implemented function to set-up DMA */
   PGA_Start();

    /* Enable Global Interrupts */
    CYGlobalIntEnable;
    
     USBUART_Start(0,USBUART_3V_OPERATION); /* se inicial el usb*/
    while(!USBUART_GetConfiguration());       /*esperamos a que se configure */
    /*el dispositivo es enumerado, habilitando los endpoint para recivir los datERos */
    USBUART_CDC_Init();
    
    USBUART_LoadInEP(USBUART_cdc_data_in_ep,adc_muestra,BUFFER_SIZE);
      ADC_SetCoherency(ADC_COHER_HIGH);   
    
    Filter_SetDalign(Filter_STAGEA_DALIGN,Filter_ENABLED);
    Filter_SetDalign(Filter_HOLDA_DALIGN,Filter_ENABLED);
    Filter_SetCoherency(Filter_STAGEA_COHER,Filter_KEY_MID);
    Filter_SetCoherency(Filter_HOLDA_COHER,Filter_KEY_MID);
    Filter_SetCoherency(Filter_CHANNEL_A,Filter_KEY_MID); 

    for(;;)
    {
        //CyPmAltAct(PM_SLEEP_TIME_NONE, PM_SLEEP_SRC_PICU);
        if(DMA_done)
        {
            CyDmaChDisable(DMA_Chan);
            CyDmaChDisable(DMA_1_Chan);
           
            /* Stop ADC Conversion for transferring the buffered data */
			ADC_StopConvert();
			
			/* Check for USB ready. */
			if(USBUART_CDCIsReady() != 0u) 
			{
				/* Transfer data - can only send 31 ADC results (64 bytes) 
				 * because UART needs null termination. */
				USBUART_LoadInEP(USBUART_cdc_data_in_ep,NULL , BUFFER_SIZE);
                
               
		
				/* Reset the flag set in DMA Done ISR */
				DMA_done = 0;
				
				/* Delay to allow for human validation of transferred data. 
				 * This is not required in a real project. */
				
				
				/* Restart ADC conversions */
				ADC_StartConvert();
                CyDmaChEnable(DMA_Chan, 1);
                CyDmaChEnable(DMA_1_Chan, 1);
			}
        }
    }
} /* End of main */



void DMA_Config(void)
{
/* DMA Configuration for DMA */
DMA_Chan = DMA_DmaInitialize(DMA_BYTES_PER_BURST, DMA_REQUEST_PER_BURST, 
    HI16(DMA_SRC_BASE), HI16(DMA_DST_BASE));
DMA_TD[0] = CyDmaTdAllocate();
CyDmaTdSetConfiguration(DMA_TD[0],2, DMA_TD[0], 0);
CyDmaTdSetAddress(DMA_TD[0], LO16((uint32)ADC_DEC_SAMP_PTR), 
                             LO16((uint32)Filter_STAGEA_PTR));
CyDmaChSetInitialTd(DMA_Chan, DMA_TD[0]);
CyDmaChEnable(DMA_Chan, 1);

}

void DMA_1_Config(void)
{

DMA_1_Chan = DMA_1_DmaInitialize(DMA_1_BYTES_PER_BURST, DMA_1_REQUEST_PER_BURST, 
    HI16(DMA_1_SRC_BASE), HI16(DMA_1_DST_BASE));
DMA_1_TD[0] = CyDmaTdAllocate();
CyDmaTdSetConfiguration(DMA_1_TD[0],sizeof(adc_muestra),DMA_1_TD[0], DMA_1__TD_TERMOUT_EN |  TD_INC_DST_ADR);
CyDmaTdSetAddress(DMA_1_TD[0], LO16((uint32)Filter_HOLDA_PTR),
                               LO16((uint32)&adc_muestra[0]));
CyDmaChSetInitialTd(DMA_1_Chan, DMA_1_TD[0]);
CyDmaChEnable(DMA_1_Chan, 1);
}


/* [] END OF FILE */
